#delim ;
version 16.1;
*
 Example 2.
 SSC packages required:
 xauto sencode sdecode parmest xcontract descsave fvregen invdesc addinby eclplot scheme_rbn1mono
*;

clear all;
set scheme rbn4mono;

* Input data *;
xauto, clear;

*
 Create trade bloc variable
*;
xcontract firm, list(, abbr(32));
gene tradebloc="USA" if us;
replace tradebloc="Japan" if inlist(firm,"Datsun","Honda","Mazda","Subaru","Toyota");
replace tradebloc="EEC" if missing(tradebloc);
lab var tradebloc "Trading bloc of firm";
sencode tradebloc, replace gsort(tradebloc);
desc tradebloc, fu;
lab list tradebloc;
xcontract tradebloc, list(, abbr(32));
xcontract tradebloc firm, list(, abbr(32) sepby(tradebloc));

*
 Create resultsframe of frequencies of tradebloc
*;
xcontract tradebloc, list(, abbr(32))
  frame(fframe, replace);

*
 Create resultsframe of variable attributes
*;
descsave tradebloc, list(, abbr(32)) frame(dframe, replace);

*
 Create resultsframe of mean fuel consumption by trade bloc
*;
regress npm ibn.tradebloc, noconst;
parmest, format(estimate min* max* %8.2f)
  list(parm estimate min* max*, abbr(32))
  frame(pframe, replace);

*
 Regenerate factor tradebloc from parameter names
*;
frame pframe {;
  fvregen;
  invdesc, dframe(dframe) lframe(dframe);
  list parm tradebloc estimate min* max*, abbr(32);  
};

*
 Add in trade bloc frequencies
*;
frame pframe {;
  fraddinby tradebloc, frame(fframe);
  list parm tradebloc _freq _percent estimate min* max*, abbr(32);    
};

*
 Create resultsplot
*;
frame pframe {;
  clonevar tradebloc2=tradebloc;
  sdecode tradebloc2, replace;
  replace tradebloc2=tradebloc2+" ("+string(_freq)+")";
  sencode tradebloc2, replace gsort(tradebloc2);
  lab var tradebloc2 "Trade bloc (frequency)";
  eclplot estimate min* max* tradebloc2,
    hori eplot(bar) estopts(barwidth(0.5))
    yscale(range(0.5 3.5)) ylab(1(1)3)
    xlab(0(1)16, format(%8.4g))
    xtitle("Mean fuel consumption (nipperkins/mile)")
    ysize(4.6) xsize(4.6);   
    ;
    graph export figseq1.pdf, replace;
};

frame dir;

exit;
